@@ -10,7 +10,10 @@ ala_GET <- function(url, path, params = list(), on_error = NULL,
       "User-Agent" = user_agent_string()
     )
   )
-  
+  # Workaround for use of 'ws/' path in base urls
+  if (!is.na(url_parse(url)$path) & !grepl("ws", path)) {
+    path <- paste0(url_parse(url)$path,"/", path)
+  }
   # workaround for fq troubles
   if (length(params$fq) > 1) {
     cli$url <- build_fq_url(url, path, params)
@@ -33,7 +36,7 @@ ala_GET <- function(url, path, params = list(), on_error = NULL,
     }
     res <- cli$get(path = path, query = params, encode = "json")
   }
-  #print(res$request$url)
+
   if (!is.null(on_error)) {
     if (res$status_code != 200) {
       on_error(res$status_code)
