@@ -21,10 +21,10 @@
 #'   \item\code{decimalLatitude}
 #'   \item\code{decimalLongitude}
 #'   \item\code{eventDate}
-#'   \item\code{taxon_name}
+#'   \item\code{scientificName}
 #'   \item\code{taxonConceptID}
 #'   \item\code{recordID}
-#'   \item\code{data_resource}
+#'   \item\code{dataResourceName}
 #' }
 #' Using \code{group = 'event'} returns the following columns:
 #' \itemize{
@@ -53,7 +53,7 @@ select_columns <- function(..., group) {
     }
 
   assertions <- search_fields(type = "assertions")$id
-  cols <- list(...)
+  cols <- c(...)
   if (length(cols) > 0) {
     validate_cols(cols)
     extra_cols <- data.table::rbindlist(lapply(cols, function(x) {
@@ -80,11 +80,8 @@ validate_cols <- function(cols) {
 
 preset_cols <- function(type) {
   valid_groups <- c("basic", "event", "assertions")
-  # use ALA version of taxon name to avoid ambiguity (2 fields map to dwc name)
   cols <- switch(type,
-                 "basic" = c("decimalLatitude", "decimalLongitude",
-                             "eventDate", "taxon_name", "taxonConceptID",
-                             "recordID", "data_resource"),
+                 "basic" = default_columns(),
                  "event" = c("eventRemarks", "eventTime", "eventID",
                              "eventDate", "samplingEffort",
                              "samplingProtocol"),
