@@ -5,6 +5,10 @@ wanted_columns <- function(type) {
                       "match_type", "kingdom", "phylum", "class", "order",
                       "family", "genus", "species", "vernacular_name",
                       "issues"),
+           "extended_taxa" = c("subkingdom", "superclass", "infraclass",
+                               "subclass", "subinfraclass", "suborder",
+                               "superorder", "infraorder", "infrafamily",
+                               "superfamily", "subfamily","subtribe", "subgenus"),
            "profile" = c("id", "name", "shortName", "description"),
            "media" = c("rightsHolder", "license", "creator", "title", "rights",
                        "mimetype", "media_id"),
@@ -56,12 +60,13 @@ build_taxa_query <- function(ids, include) {
   value_str
 }
 
-build_query <- function(taxa, filters, locations, columns = NULL) {
-  
+build_query <- function(taxa, filters, locations, columns = NULL,
+                        profile = NULL) {
   query <- list()
   if (is.null(taxa)) {
     taxa_query <- NULL
   } else {
+    check_taxa_arg(taxa)
     include <- !inherits(taxa, "exclude")
     if (inherits(taxa, "data.frame") &&
         "taxon_concept_id" %in% colnames(taxa)) {
@@ -76,7 +81,13 @@ build_query <- function(taxa, filters, locations, columns = NULL) {
     filter_query <- NULL
   } else {
     assert_that(is.data.frame(filters))
-    filter_query <- build_filter_query(filters)
+    # remove profile from filter rows
+    filters <- filters[filters$name != "profile",]
+    if (nrow(filters) == 0) {
+      filter_query <- NULL
+    } else {
+      filter_query <- build_filter_query(filters)
+    }
   }
   
   query$fq <- c(taxa_query, filter_query)
@@ -90,19 +101,73 @@ build_query <- function(taxa, filters, locations, columns = NULL) {
   if (check_for_caching(taxa_query, filter_query, area_query, columns)) {
     query <- cached_query(taxa_query, filter_query, area_query)
   }
+  if (getOption("galah_config")$atlas == "Australia") {
+    if (!is.null(profile)) {
+      query$qualityProfile <- profile
+    } else {
+      query$disableAllQualityFilters <- "true"
+    }
+  }
   query
 }
 
+# takes a dataframe and returns a built filter query
+build_filter_query <- function(filters) {
+  mapply(query_term, filters$name, filters$value, filters$include,
+         USE.NAMES = FALSE)
+}
+
+query_term <- function(name, value, include) {
+  # add quotes around value
+  value <- lapply(value, function(x) {
+    # don't add quotes if there are square brackets in the term
+    if (grepl("\\[", x)) {
+      x
+    } else {
+      paste0("\"", x, "\"")
+    }
+  })
+  # add quotes around value
+  if (include) {
+    value_str <- paste0("(", paste(name, value, collapse = " OR ", sep = ":"),
+                        ")")
+  } else {
+    value_str <- paste0("(", paste(paste0("-", name), value,
+                                   collapse = ' AND ', sep = ":"), ")")
+  }
+  #paste0("(", value_str, ")")
+  value_str
+}
+
+
+filter_value <- function(val) {
+  # replace logical values with strings
+  if (is.logical(val)) {
+    return(ifelse(val, "true", "false"))
+  }
+  val
+}
+
 # this is only relevant for ala_counts and ala_occurrences
 cached_query <- function(taxa_query, filter_query, area_query,
                          columns = NULL) {
-  url <- getOption("galah_server_config")$base_url_biocache
+  url <- server_config("records_base_url")
   resp <- ala_POST(url, path = "ws/webportal/params",
                    body = list(wkt = area_query, fq = taxa_query,
                                fields = columns))
   list(fq = filter_query, q = paste0("qid:", resp))
 }
 
+
+extract_profile <- function(filters) {
+  profile <- NULL
+  if (!is.null(filters)){
+    profile_row <- filters[filters$name == "profile",]
+    if (nrow(profile_row) == 1) { profile <- profile_row$value[[1]] }
+  }
+  profile
+}
+
 # Check whether caching of some url parameters is required.
 # Note: it is only possible to cache one fq so filters can't be cached
 check_for_caching <- function(taxa_query, filter_query, area_query,
@@ -130,8 +195,7 @@ build_columns <- function(col_df) {
   if (nrow(col_df) == 0) {
     return("")
   }
-  ala_cols <- dwc_to_ala(col_df$name)
-  paste0(ala_cols, collapse = ",")
+  paste0(col_df$name, collapse = ",")
 }
 
 user_agent_string <- function() {
@@ -142,4 +206,11 @@ user_agent_string <- function() {
   paste0("galah ", version_string)
 }
 
-
+# Check taxonomic argument provided to `ala_` functions is of correct form
+check_taxa_arg <- function(taxa) {
+  if (!any(grepl("id", class(taxa)))) {
+    if (!any(grepl("\\d", taxa))) {
+      stop("`select_taxa` requires an identifier input generated by `select_taxa()` or a `taxize` function.")
+    }
+  }
+}
