@@ -2,5 +2,5 @@ library(testthat)
 library(galah)
 
 ala_config(cache_directory = tempdir(), email = "ala4r@ala.org.au",
-           caching = FALSE)
+           caching = FALSE, atlas = "Australia", verbose = FALSE)
 test_check("galah")
