@@ -5,7 +5,7 @@ test_that("ala config sets default options", {
   # set to null
   options(galah_config = NULL)
   # check that defaults are used
-  expect_equal(ala_config()$verbose, FALSE)
+  expect_equal(ala_config()$verbose, TRUE)
 })
 
 test_that("ala config checks inputs", {
@@ -18,5 +18,7 @@ test_that("ala config checks inputs", {
   expect_silent(ala_config(download_reason_id = "Testing"))
   expect_error(ala_config(download_reason_id = "tsting"))
   expect_error(ala_config(cache_directory = "non/existent/dir"))
-  expect_error(bad_option = "value")
+  expect_error(ala_config(bad_option = "value"))
+  expect_error(ala_config(atlas = "world"))
+  expect_silent(ala_config(atlas = "Australia"))
 })
